aboutsummaryrefslogtreecommitdiffstats
path: root/include/osmosdr/osmosdr_source_c.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/osmosdr/osmosdr_source_c.h')
-rw-r--r--include/osmosdr/osmosdr_source_c.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/osmosdr/osmosdr_source_c.h b/include/osmosdr/osmosdr_source_c.h
index 1da922b..425902d 100644
--- a/include/osmosdr/osmosdr_source_c.h
+++ b/include/osmosdr/osmosdr_source_c.h
@@ -148,16 +148,16 @@ public:
/*!
* Set the gain mode for the underlying radio hardware.
* This might be supported only for certain hardware types.
- * \param mode the gain mode (true means automatic gain mode)
+ * \param automatic the gain mode (true means automatic gain mode)
* \param chan the channel index 0 to N-1
* \return the actual gain mode
*/
- virtual bool set_gain_mode( bool mode, size_t chan = 0 ) = 0;
+ virtual bool set_gain_mode( bool automatic, size_t chan = 0 ) = 0;
/*!
* Get the gain mode selected for the underlying radio hardware.
* \param chan the channel index 0 to N-1
* \return the actual gain mode
*/
virtual bool get_gain_mode( size_t chan = 0 ) = 0;
@@ -148,16 +148,16 @@ public:
* Get the gain mode selected for the underlying radio hardware.
* \param chan the channel index 0 to N-1
- * \return the actual gain mode
+ * \return the actual gain mode (true means automatic gain mode)
*/
virtual bool get_gain_mode( size_t chan = 0 ) = 0;